@@ -1,8 +1,23 @@
-tile.list <- function (object) {
+tile.list <- local({
+edgeLengths <- function(x,y) {
+    n <- length(x)
+    el <- numeric(n) 
+    for(i in 1:n) {
+        ii <- if(i < n) i+1 else 1
+        el[i] <- sqrt((x[i] - x[ii])^2 + (y[i] - y[ii])^2)
+    } 
+    el 
+}
+
+function (object,minEdgeLength=NULL) {
   if (!inherits(object, "deldir"))
     stop("Argument \"object\" is not of class \"deldir\".\n")
   ptp <- object$summary$pt.type
   rw <- object$rw
+  if(is.null(minEdgeLength)) {
+    drw <- sqrt((rw[2] - rw[1])^2 + (rw[4] - rw[3])^2)
+    minEdgeLength <- drw*sqrt(.Machine$double.eps)
+  }
   x.crnrs <- rw[c(1, 2, 2, 1)]
   y.crnrs <- rw[c(3, 3, 4, 4)]
   ddd <- object$dirsgs
@@ -16,9 +31,9 @@ tile.list <- function (object) {
   rslt <- list()
   ind.orig <- object$ind.orig
   for (i in 1:npts) {
-    filter1 = ddd$ind1 == i
-    filter2 = ddd$ind2 == i
-    subset = ddd[which(filter1 | filter2),]
+    filter1 <- ddd$ind1 == i
+    filter2 <- ddd$ind2 == i
+    subset  <- ddd[which(filter1 | filter2),,drop=FALSE]
     m <- matrix(unlist(subset[, 1:4]), ncol = 4)
     bp1 <- subset[, 7]
     bp2 <- subset[, 8]
@@ -28,7 +43,7 @@ tile.list <- function (object) {
     pt <- c(x = sss$x[i], y = sss$y[i])
     theta <- atan2(m[, 2] - pt[2], m[, 1] - pt[1])
     theta.0 <- sort(unique(theta))
-    mm <- m[match(theta.0, theta), ]
+    mm <- m[match(theta.0, theta),,drop=FALSE]
     xx <- mm[, 1]
     yy <- mm[, 2]
     bp <- as.logical(mm[, 3])
@@ -42,12 +57,17 @@ tile.list <- function (object) {
                 y     = unname(yy),
                 bp    = bp,
                 area  = sss$dir.area[i])
-
+    tmp    <- acw(tmp)
+    bird   <- edgeLengths(tmp$x,tmp$y)
+    ok     <- bird >= minEdgeLength
+    tmp$x  <- tmp$x[ok]
+    tmp$y  <- tmp$y[ok]
+    tmp$bp <- tmp$bp[ok]
     if(length(ptp)) {
       tmp <- append(tmp,values=ptp[i],after=2)
       names(tmp)[3] <- "ptType"
     }
-    rslt[[i]] <- acw(tmp)
+    rslt[[i]] <-acw(tmp)
     if(haveZ)
       rslt[[i]]["z"] <- z[i]
   }
@@ -56,6 +76,8 @@ tile.list <- function (object) {
   return(rslt)
 }
 
+})
+
 "[.tile.list" <- function(x,i,...){
     y <- unclass(x)[i]
     class(y) <- "tile.list"
